==> kadu_3.0~rc1.orig.tar.bz2: kadu-3.0-rc1/plugins/filedesc/translations/filedesc_pt_BR.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt_BR">
<context>
    <name>@default</name>
    <message>
        <source>FileDesc</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>File with description to synchronize</source>
        <translation>Arquivo com descrição para sincronizar</translation>
    </message>
    <message>
        <source>Enter here a file, which will contain descriptions to refresh by module.</source>
        <translation>Selecione um arquivo que irá conter as descrições para atualizar pelo módulo.</translation>
    </message>
    <message>
        <source>If you choose status without description, module will set it automatically to similar but with description</source>
        <translation>Se voce escolher um status sem descrição, o módulo irá automaticamente utilizar um similar, mas com descrição</translation>
    </message>
    <message>
        <source>Allow other descriptions</source>
        <translation>Permitir outras descrições</translation>
    </message>
    <message>
        <source>Allows you to set some custom description manualy, until file contents does not change</source>
        <translation>Permite que você defina algumas descrições personalizadas manualmente, enquanto o conteúdo do arquivo não muda</translation>
    </message>
    <message>
        <source>Behavior</source>
        <translation>Comportamento</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Descrição</translation>
    </message>
    <message>
        <source>Always add description to status</source>
        <translation>Sempre insira a descrição para o status</translation>
    </message>
</context>
</TS>

==> kadu_4.1.orig.tar.bz2: kadu-4.1/plugins/filedesc/translations/filedesc_pt_BR.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="pt_BR" version="2.1">
<context>
    <name>@default</name>
    <message>
        <source>FileDesc</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>File with description to synchronize</source>
        <translation>Arquivo com descrição para sincronizar</translation>
    </message>
    <message>
        <source>Enter here a file, which will contain descriptions to refresh by module.</source>
        <translation>Selecione um arquivo que irá conter as descrições para atualizar pelo módulo.</translation>
    </message>
    <message>
        <source>If you choose status without description, module will set it automatically to similar but with description</source>
        <translation>Se voce escolher um status sem descrição, o módulo irá automaticamente utilizar um similar, mas com descrição</translation>
    </message>
    <message>
        <source>Allow other descriptions</source>
        <translation>Permitir outras descrições</translation>
    </message>
    <message>
        <source>Allows you to set some custom description manualy, until file contents does not change</source>
        <translation>Permite que você defina algumas descrições personalizadas manualmente, enquanto o conteúdo do arquivo não muda</translation>
    </message>
    <message>
        <source>Behavior</source>
        <translation>Comportamento</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Descrição</translation>
    </message>
    <message>
        <source>Always add description to status</source>
        <translation>Sempre insira a descrição para o status</translation>
    </message>
</context>
</TS>
